@@ -4,9 +4,6 @@ import * as lambda from 'aws-cdk-lib/aws-lambda';
 import * as apigateway from 'aws-cdk-lib/aws-apigateway';
 import * as logs from 'aws-cdk-lib/aws-logs';
 
-/**
- * For copying shared code to all paths
- */
 import * as fse from 'fs-extra';
 
 export interface LambdasByPath {
@@ -104,8 +101,10 @@ interface FSGraph {
 }
 
 export class CrowApi extends Construct {
-  public authorizerLambda!: lambda.Function;
   public gateway!: apigateway.RestApi;
+  public usagePlan!: apigateway.UsagePlan;
+  public authorizer!: apigateway.IAuthorizer;
+  public authorizerLambda!: lambda.Function;
   public lambdaLayer!: lambda.LayerVersion | undefined;
   public lambdaFunctions!: LambdasByPath;
   public models!: { [modelName: string]: apigateway.IModel };
@@ -239,6 +238,7 @@ export class CrowApi extends Construct {
         ],
       });
       usagePlan.addApiKey(apiKey);
+      this.usagePlan = usagePlan;
     }
 
     // Create Lambda layer out of shared directory if it exists
@@ -274,6 +274,7 @@ export class CrowApi extends Construct {
         'token-authorizer',
         bundledTokenAuthConfig
       );
+      this.authorizer = tokenAuthorizer;
     }
 
     // Time to start walking the directories
